# Summary

All default settings have been thought to be the **most logic behaviour you could expect in your application**, using jQuery 
properties to dynamically find out how the functions should work at a given moment.

In other words, this is a big wrapper mixing animations display and some logic, to achieve complex HTML elements operations in
one single line.

This plugin has been built with https://github.com/hupiat/jQueryOrchestrator

# Features

## Fade

This function allows to perform fade in and fade out animations

![Screenshot](gifs/Fade.gif)

#### Usage 

`$(element).EnlivenTricks().fade(settings);`

#### Settings

* **duration**: animation duration (500 by default)
* **mode**: **'in'** or **'out'**, by default the plugin will check element visibility, if it's invisible the mode will be 'in', 'out' otherwise
* **disappear**: boolean value, indicates if the element should be as 'displayed: none' after fading, **only used when mode is 'out'** (false by default)

## Shake

This function allows to perform shaking animation 

![Screenshot](gifs/Shake.gif)

#### Usage

`$(element).EnlivenTricks().shake(settings);`

#### Settings

* **times**: number of shakes to perform (6 by default), **note that the animation duration will not be altered**, since it's computed according to the shakes number
* **wrapper**: parent wrapper reference (false by default), this setting is useful when you are working on an element you want to animate, but because of
a css framework the shaking is not made as you wanted, here you can give a HTML parent on which the animation should be performed

## Blob

This function applies an effect when hovering the element, enlarging its size and shadowing it

![Screenshot](gifs/Blob.gif)

#### Usage

`$(element).EnlivenTricks().blob();`

#### Settings

There is no settings here, note that at each call, the blob class will be added if not present, **or removed if already present**

## Swap

This function allows you to switch between views using sliding fade effects

![Screenshot](gifs/Swap.gif)

#### Usage

`$(element).EnlivenTricks().swap(settings);`

#### Settings

* **callback** callback function to execute when all animations are done
* **vertical** boolean value indicating if the animation should be performed in a vertical way, false by default
* **next** reference of the next container to show, by default this can be fetched automatically using class pattern **swappable-${n}**,
with n the container number in the page sequence
* **revert** should the animation be reverted (false by default). If this option is coupled with auto-fetch, the next element selected will be the one matching with the pattern **swappable-${n-1}**
 
## Load

This function allows you to insert a loader into a HTML container

![Screenshot](gifs/Load.gif)

#### Usage

`$(element).EnlivenTricks().load(settings);`

#### Settings

* **position** json object containing properties left / top / bottom / right **handling position in CSS way**. By default the loader will be centered 
* **color** loader color, this option supports all CSS formats, white by default
* **appearance** defines loader appearance, availables values are :
    * **'square'**
    * **'flash'**
    * **'disk'**
    * **'spinner'**
    * **'fixed-spinner'**
    * **'classic-spinner'**
    * **'simple'** (used by default)
* **delayHandler** this option is used to handle display duration, it can be : 
    * **an integer**, representing the duration in ms
    * **the keyword 'infinite'**, meaning the loader won't disappear
    * **a function or a promise**, in this case the loader will disappear when your background work is over

    By default the delayHandler is set at 5000 ms

## Morphing

This function allows you to switch between icon appearances with smooth transitions

![Screenshot](gifs/Morph.gif)

#### Usage

`$(element).EnlivenTricks().morph(settings);`

with the element such as **`<i>icon_value</i>`**

#### Settings

* **next** string value of next icon
* **morphing** animation type, available values are :
    * **'rotate'**
    * **'vibrate'**
    * **'flip'**
    * **'fade'**
    * **'huff'** (used by default)

## Events

Every element will fire an event "**EnlivenTricks**" -> **function(settings, feature)** when animating

There is shortcut for each function such as "**EnlivenTricks::{ fade, shake, load, swap, blob, morph }**" -> **function(settings)**

## Magic

This function provides you a wrapped set of utilities functions, allowing you to put some global logic in your animations
    
#### Usage

`$.fn.EnlivenTricks().magic(...wizards)._____(argsOrNotArgs);`

where the wizards are objects like **{ selector: '#htmlSelector', callback: someWorkToDo(myElementSelected) }**

* **reveal()** : performs the callback when the wizards are revealed by scrolling, returns MagicTrick() instance
* **factorize()** : returns a promise allowing you to execute all the callbacks in one time and in async way
* **defeer(delay)** : executes all the callbacks one by one, with a sleep time (delay: 200 by default), returns MagicTrick() instance

