/**
 * Gets class rule
 * @param {string} className class to describe
 * @param {string} attribute attribute to describe
 * @returns {string} attribute value
 */
function _cssRule(className, attribute) {
    
    className = className.replace('.', '');
    const spy = $(`<div id='evSpy-${_generateToken()}' class='${className}' 
        style='display: none !important;'></div>`).appendTo('body');
    className = `.${className}`;
    
    const css = (!attribute ? spy.css() : spy.css(attribute));
    $(spy).remove();
    return css;
}

/**
 * Events triggerer
 * @param {string} feature feature name
 * @param {string} target target element reference
 * @param {object} settings event settings
 */
function _trigger(feature, target, settings) {

    const mainEvent = 'EnlivenTricks';
    const event = `${mainEvent}::${feature}`;
    $(target).trigger(event, [settings]);
    $(target).trigger(mainEvent, [settings, feature]);
}

/**
 * Gets HTML class list
 * @param {object} target target element reference
 */
function _classList(target) {

    return $(target).prop('class')
                .split(' ')
                .map(elt => elt.trim());
}

/**
 * Generates a random token
 * @returns generated token as string
 */
function _generateToken() {

    const rand = () => Math.random().toString(36).substr(2);
    return rand() + rand();
}

/**
 * Checks element css 'position' 
 * attribute and update its value if needed
 * @param {string} element element reference
 */
function _checkPositionState(element) {
    
    const DEFAULT = 'relative';
    const attribute = $(element).css('position');

    if (attribute !== 'relative' &&
        attribute !== 'absolute' && attribute !== 'fixed') {

        $(element).css('position', DEFAULT);
    }
}

/**
 * Checks element blob class and remove it if present
 * @param {string} element element reference
 * @returns true if blob class has been removed, false otherwise 
 */
function _checkBlobState(element) {
    
    const isBlob = $(element).hasClass(_BLOB_CLASS);

    if (isBlob) {
        $(element).removeClass(_BLOB_CLASS);
    }
    return isBlob;
}