/**
 * Single access point to loaders
 * @param {string} loaderFlag textual representation of the loader appearance
 * @param {object} data object containing the loader id, style, and the style of the child divs
 * @returns loader HTML code
 */
function _LOADER_FACTORY(loaderFlag, data) {

    const build = (childsNumber, data, className) => {

        let strBuilt = `<div id='${data.id}' style='${data.style}' class='${className}'>`;
        for (let i = 0; i < childsNumber; i++) {
            strBuilt += `<div style='${data.childStyle}'></div>`;
        }
        return `${strBuilt}</div>`;
    }

    switch (loaderFlag.toLowerCase()) {

        case 'square':
            return build(9, data, 'enliven-loader-square');

        case 'flash':
            const color = data.childStyle.split(':')[1].trim().replace(';', '');
            data.childStyle = `border: 4px solid ${color};`;
            return build(2, data, 'enliven-loader-flash');

        case 'fixed-spinner':
            return build(12, data, 'enliven-loader-fixed-spinner');

        case 'classic-spinner':
            return build(12, data, 'enliven-loader-classic-spinner');

        case 'spinner':
            return build(8, data, 'enliven-loader-spinner');

        case 'disk':
            return build(1, data, 'enliven-loader-disk');

        default:
            return build(4, data, 'enliven-loader');
    }
}