/**
 * Performs fading animation
 * @param {object} settings 
 * -- duration = fade duration (default: 500 ms)
 * -  mode = 'in' / 'out' (default: in if the element is invisible, out otherwise) 
 * -  disappear = when mode is out, should the element be removed (default: false)
 * 
 * @Feature (name=fade)
 */
function FadeTrick(settings) {

    settings = $.extend({
        duration: 500, 
        disappear: false
    }, settings);

    settings.duration = parseInt(settings.duration);
    return this.each(function() {

        if (!settings.mode) {
            // Defining fade mode depending on element visibility
            const visible = ($(this).is(':visible') && parseInt($(this).css('opacity')) !== 0);
            settings.mode = (visible ? 'out' : 'in');
        } else if (settings.mode !== 'out' && settings.mode !== 'in') {
            console.error(`FadeTrick: invalid mode '${settings.mode}'`);
            return;
        }

        if ($(this).is(':animated')) {
            return;
        } else if (settings.mode === 'in') {
            $(this).show();
        }
        _trigger('fade', this, settings);

        $(this).animate({
            opacity: (settings.mode === 'in' ? 1 : 0)
        }, settings.duration, function() {

            if (settings.mode === 'out' && settings.disappear) {
                $(this).hide();
            }
        });
    });
}