/**
 * Displays a loader appended on the element 
 * @param {object} settings 
 * -- position = json object containing properties left / right / bottom / top (default: centered)
 * -  color = loader color (default: white)
 * -  appearance = loader appearance (default: simple) 
 * -  delayHandler = can be the function to execute while loading, a delay in ms, or 'infinite' (default: 5000 ms)
 * 
 * @Feature (name=load)
 */
function LoadTrick(settings) {

    settings = $.extend({
        color: 'white',
        appearance: 'simple',
        position: { left: -1, right: 0, bottom: 0, top: -1 },
        delayHandler: 5000
    }, settings);

    return this.each(function() {

        $(this).children().each(function() {
            if ($(this).prop('id').startsWith('evLoader')) {
                $(this).remove();
            }
        });

        // Checking some position constraints
        for (const item of _classList(this)) {
            if (item.includes('center')) {
                settings.position.left = 0;
                break;
            }
        }

        // Computing center position
        if (settings.position.top === -1) {
            settings.position.top = ($(this).height() + parseInt($(this).css('paddingTop')) 
                + parseInt($(this).css('paddingBottom'))) / 2 - 32;
        }
        if (settings.position.left === -1) {
            settings.position.left = ($(this).width() + parseInt($(this).css('paddingLeft')) 
                + parseInt((this).css('paddingRight'))) / 2 - 32;
        }
        _trigger('load', this, settings);

        const style = `
            position: relative;
            left: ${settings.position.left}px;
            top: ${settings.position.top}px;
            bottom: ${settings.position.bottom}px;
            right: ${settings.position.right}px;`;

        const id = `evLoader-${_generateToken()}`;

        const childStyle = `background: ${settings.color};`;

        const loader = _LOADER_FACTORY(settings.appearance, {
            id: id,
            style: style,
            childStyle: childStyle
        });
        
        $(loader).appendTo(this);

        const remover = () => $(`#${id}`).remove();

        if (settings.delayHandler instanceof Function) {
            setTimeout(function() {

                if (settings.delayHandler instanceof Promise) {
                    settings.delayHandler().then(remover).catch(function(err) {
                        remover();
                        console.error(err);
                    });
                } else {
                    settings.delayHandler();
                    remover();
                }
            }, 1);
        } else if (settings.delayHandler !== 'infinite') {
            setTimeout(remover, parseInt(settings.delayHandler));
        } 
    });
}