/**
 * Performs shaking animation
 * @param {object} settings 
 * -- times = number of shakes (default: 6)
 * -  wrapper = parent wrapper reference (default: false) 
 * 
 * @Feature (name=shake)
 */
function ShakeTrick(settings) {

    settings = $.extend({
        times: 6, 
        wrapper: false
    }, settings);

    settings.times = parseInt(settings.times);
    if (settings.times % 2 !== 0) settings.times--;
    if (settings.times > 24) settings.times = 24;

    const duration = 500 / settings.times;
    return this.each(function() {

        let count = 0;
        let $that = $(this);

        if (settings.wrapper !== false) {
            // Getting wrapper element
            const wrapper = $(settings.wrapper);
            if (wrapper.length) $that = wrapper;
        }

        if ($that.is(':animated')) return;
        _trigger('shake', this, settings);

        const wasBlob = _checkBlobState($that);
        _checkPositionState($that);

        const even = () => count % 2 === 0;
        const callback = function() {
            
            const shift = (count < 1 || count === settings.times - 1 ? '30' : '60');

            $that.animate({ 
                left: `${ even() ? '+' : '-' }=${shift}`
            }, duration, function() {

                count++;
                if (count < settings.times) {
                    // Looping until anim is complete
                    callback();
                } else if (wasBlob === true) {
                    // Then restoring blob state
                    $that.addClass(_BLOB_CLASS);
                }
            })
        }
        callback();
    });
}