/**
 * Performs swap effect between two containers
 * @param {object} settings
 * -- next = reference of new container to show, can be computed with classes
 * matching the pattern swappable-${number}
 * -  revert = boolean indicating if the animation should be performed
 * in the left direction (default: false)
 * -  callback = callback function to execute after animation
 * -  vertical = if the animation should be vertical (default: false) 
 * 
 * @Feature (name=swap)
 */
function SwapTrick(settings) {
    
    settings = $.extend({
        revert: false, 
        vertical: false, 
        callback: () => { return; }
    }, settings);

    const duration = 600;
    return this.each(function() {

        if ($(this).is(':animated')) return;

        // Dynamic reference to next element using class pattern
        if (!settings.next) {
            let swappableClass;
            for (const item of _classList(this)) {
                if (item.startsWith('swappable')) {
                    swappableClass = item;
                    break;
                }
            }
            // Parsing class name and computing next element reference
            if (swappableClass) {
                const split = swappableClass.split('-');
                if (split.length > 1 && parseInt(split[1])) {
                    const current = parseInt(split[1]);
                    const next = `.swappable-${settings.revert ? current - 1 : current + 1}`;
                    // Checking if such class owner exists
                    if ($(next).length) settings.next = next;
                }
            }
            if (!settings.next) {
                console.error('SwapTrick: next reference could not be found, classes should follow the pattern swappable-${number}');
                return;
            }
        }
        _trigger('swap', this, settings);
        _checkPositionState(this);
        _checkPositionState(settings.next);
        const thisWasBlob = _checkBlobState(this);
        const nextWasBlob = _checkBlobState(settings.next);
        const propertyName = (settings.vertical ? 'bottom' : 'left');

        if ($(settings.next).css(propertyName) === 'auto') {
            $(settings.next).css(propertyName, '0');
        }
        $(settings.next).css(propertyName, `${settings.revert ? '+' : '-'}=1000`);
        $(settings.next).css('opacity', '0');

        const $that = $(this);
        const oldProperty = $that.css(propertyName);

        // Sliding out first element
        let animData = { opacity: 0 };
        animData[propertyName] = `${settings.revert ? '-' : '+'}=1000`;
        $that.animate(animData, duration, function() {

            if (thisWasBlob) {
                $that.addClass(_BLOB_CLASS);
            }
        });
        
        setTimeout(function() {
            $that.hide();
            $(settings.next).show();
            // Showing next element
            animData.opacity = 1;
            $(settings.next).animate(animData, duration, function() {

                $that.css(propertyName, oldProperty);
                settings.callback();
                if (nextWasBlob) {
                    $(settings.next).addClass(_BLOB_CLASS);
                }
            });
        }, duration - 150);
    });
}